@@ -59,6 +59,7 @@
 // Copyright (C) 2024 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by Technische Universität Dresden
 // Copyright (C) 2025 Juraj Šarinay <juraj@sarinay.com>
 // Copyright (C) 2025 Jonathan Hähne <jonathan.haehne@hotmail.com>
+// Copyright (C) 2025 Arnav V <arnav0872@gmail.com>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -70,7 +71,6 @@
 
 #include <array>
 #include <cctype>
-#include <clocale>
 #include <cstdio>
 #include <cerrno>
 #include <climits>
@@ -83,10 +83,9 @@
 #include <sstream>
 #include <sys/stat.h>
 #include "CryptoSignBackend.h"
-#include "goo/glibc.h"
-#include "goo/gstrtod.h"
 #include "goo/GooString.h"
 #include "goo/gfile.h"
+#include "goo/glibc.h"
 #include "GlobalParams.h"
 #include "Page.h"
 #include "Catalog.h"
@@ -97,7 +96,6 @@
 #include "OutputDev.h"
 #include "Error.h"
 #include "Lexer.h"
-#include "Parser.h"
 #include "SecurityHandler.h"
 #include "Decrypt.h"
 #include "Outline.h"
@@ -237,8 +235,8 @@ bool PDFDoc::setup(const std::optional<GooString> &ownerPassword, const std::opt
         return false;
     }
 
-    if (!str->reset()) {
-        error(errSyntaxError, -1, "Document base stream reset failure");
+    if (!str->rewind()) {
+        error(errSyntaxError, -1, "Document base stream rewind failure");
         errCode = errFileIO;
         return false;
     }
@@ -1057,7 +1055,7 @@ int PDFDoc::saveWithoutChangesAs(OutStream *outStr)
     }
 
     std::unique_ptr<BaseStream> copyStr { str->copy() };
-    if (!copyStr->reset()) {
+    if (!copyStr->rewind()) {
         return errFileIO;
     }
     while (copyStr->lookChar() != EOF) {
@@ -1077,7 +1075,7 @@ void PDFDoc::saveIncrementalUpdate(OutStream *outStr)
 {
     // copy the original file
     std::unique_ptr<BaseStream> copyStr { str->copy() };
-    if (!copyStr->reset()) {
+    if (!copyStr->rewind()) {
         // some err;
     }
     while (copyStr->lookChar() != EOF) {
@@ -1263,7 +1261,7 @@ void PDFDoc::writeDictionary(Dict *dict, OutStream *outStr, XRef *xRef, unsigned
 
 void PDFDoc::writeStream(Stream *str, OutStream *outStr)
 {
-    if (!str->reset()) {
+    if (!str->rewind()) {
         return;
     }
     outStr->printf("stream\r\n");
@@ -1289,8 +1287,8 @@ void PDFDoc::writeRawStream(Stream *str, OutStream *outStr)
     }
 
     outStr->printf("stream\r\n");
-    if (!str->unfilteredReset()) {
-        error(errSyntaxError, -1, "PDFDoc::writeRawStream, reset failed");
+    if (!str->unfilteredRewind()) {
+        error(errSyntaxError, -1, "PDFDoc::writeRawStream, rewind failed");
         return;
     }
     for (Goffset i = 0; i < length; i++) {
@@ -1301,7 +1299,7 @@ void PDFDoc::writeRawStream(Stream *str, OutStream *outStr)
         }
         outStr->printf("%c", c);
     }
-    (void)str->reset();
+    (void)str->rewind();
     outStr->printf("\r\nendstream\r\n");
 }
 
@@ -1313,7 +1311,7 @@ void PDFDoc::writeString(const GooString *s, OutStream *outStr, const unsigned c
         EncryptStream *enc = new EncryptStream(new MemStream(s->c_str(), 0, s->size(), Object::null()), fileKey, encAlgorithm, keyLength, ref);
         sEnc = std::make_unique<GooString>();
         int c;
-        if (!enc->reset()) {
+        if (!enc->rewind()) {
             return;
         }
         while ((c = enc->getChar()) != EOF) {
@@ -1469,7 +1467,7 @@ void PDFDoc::writeObject(Object *obj, OutStream *outStr, XRef *xRef, unsigned in
                 stream = encStream.get();
             }
 
-            if (!stream->reset()) {
+            if (!stream->rewind()) {
                 break;
             }
             // recalculate stream length
@@ -1664,7 +1662,7 @@ void PDFDoc::writeXRefTableTrailer(Goffset uxrefOffset, XRef *uxref, bool writeA
     // file size (doesn't include the trailer)
     unsigned int fileSize = 0;
     int c;
-    if (!str->reset()) {
+    if (!str->rewind()) {
         return;
     }
     while ((c = str->getChar()) != EOF) {
@@ -2163,7 +2161,7 @@ std::unique_ptr<Page> PDFDoc::parsePage(int page)
     }
     Dict *pageDict = obj.getDict();
 
-    return std::make_unique<Page>(this, page, std::move(obj), pageRef, std::make_unique<PageAttrs>(nullptr, pageDict), catalog->getForm());
+    return std::make_unique<Page>(this, page, std::move(obj), pageRef, std::make_unique<PageAttrs>(nullptr, pageDict));
 }
 
 Page *PDFDoc::getPage(int page)
