@@ -34,7 +34,9 @@
 // Copyright (C) 2020, 2021, 2025 Nelson Benítez León <nbenitezl@gmail.com>
 // Copyright (C) 2020 Philipp Knechtges <philipp-dev@knechtges.com>
 // Copyright (C) 2024 Pablo Correa Gómez <ablocorrea@hotmail.com>
-// Copyright (C) 2024, 2025 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2024-2026 g10 Code GmbH, Author: Sune Stolborg Vuorela <sune@vuorela.dk>
+// Copyright (C) 2025 Stefan Brüns <stefan.bruens@rwth-aachen.de>
+// Copyright (C) 2025 Arnav V <arnav0872@gmail.com>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -43,7 +45,6 @@
 
 #include <config.h>
 
-#include <cstddef>
 #include <climits>
 #include "GlobalParams.h"
 #include "Object.h"
@@ -61,34 +62,48 @@
 #include "Error.h"
 #include "Page.h"
 #include "Catalog.h"
+#include "goo/gmem.h"
 
 //------------------------------------------------------------------------
 // PDFRectangle
 //------------------------------------------------------------------------
 
-void PDFRectangle::clipTo(PDFRectangle *rect)
-{
-    if (x1 < rect->x1) {
-        x1 = rect->x1;
-    } else if (x1 > rect->x2) {
-        x1 = rect->x2;
-    }
-    if (x2 < rect->x1) {
-        x2 = rect->x1;
-    } else if (x2 > rect->x2) {
-        x2 = rect->x2;
-    }
-    if (y1 < rect->y1) {
-        y1 = rect->y1;
-    } else if (y1 > rect->y2) {
-        y1 = rect->y2;
-    }
-    if (y2 < rect->y1) {
-        y2 = rect->y1;
-    } else if (y2 > rect->y2) {
-        y2 = rect->y2;
-    }
-}
+namespace {
+namespace testing {
+static_assert(PDFRectangle {} == PDFRectangle {});
+static_assert(PDFRectangle { 0, 0, 1, 1 } == PDFRectangle { 0, 0, 1, 1 });
+static_assert(PDFRectangle { 0, 0, 1, 1 }.isValid());
+static_assert(!PDFRectangle { 0, 0, 0, 0 }.isValid());
+static_assert(PDFRectangle { 0, 0, 2, 2 }.contains(1, 1));
+static_assert(!PDFRectangle { 0, 0, 1, 2 }.contains(2, 1));
+
+constexpr PDFRectangle r1 { 0, 0, 5, 5 };
+constexpr PDFRectangle r2 { 2, 2, 4, 4 };
+constexpr PDFRectangle r3 { 0, 3, 3, 3 };
+constexpr PDFRectangle r4 { 2, 3, 3, 3 };
+static_assert(r1.isValid());
+static_assert([]() {
+    auto r = r1;
+    r.clipTo(r1);
+    return r == r1;
+}());
+static_assert([]() {
+    auto r = r1;
+    r.clipTo(r2);
+    return r == r2;
+}());
+static_assert([]() {
+    auto r = r2;
+    r.clipTo(r1);
+    return r == r2;
+}());
+static_assert([]() {
+    auto r = r2;
+    r.clipTo(r3);
+    return r == r4;
+}());
+} // namespace testing
+} // namespace
 
 //------------------------------------------------------------------------
 // PageAttrs
@@ -184,10 +199,10 @@ PageAttrs::~PageAttrs() = default;
 
 void PageAttrs::clipBoxes()
 {
-    cropBox.clipTo(&mediaBox);
-    bleedBox.clipTo(&mediaBox);
-    trimBox.clipTo(&mediaBox);
-    artBox.clipTo(&mediaBox);
+    cropBox.clipTo(mediaBox);
+    bleedBox.clipTo(mediaBox);
+    trimBox.clipTo(mediaBox);
+    artBox.clipTo(mediaBox);
 }
 
 bool PageAttrs::readBox(Dict *dict, const char *key, PDFRectangle *box)
@@ -252,7 +267,7 @@ bool PageAttrs::readBox(Dict *dict, const char *key, PDFRectangle *box)
 
 #define pageLocker() const std::scoped_lock locker(mutex)
 
-Page::Page(PDFDoc *docA, int numA, Object &&pageDict, Ref pageRefA, std::unique_ptr<PageAttrs> attrsA, Form *form) : pageRef(pageRefA), attrs(std::move(attrsA))
+Page::Page(PDFDoc *docA, int numA, Object &&pageDict, Ref pageRefA, std::unique_ptr<PageAttrs> attrsA) : pageRef(pageRefA), attrs(std::move(attrsA))
 {
     ok = true;
     doc = docA;
@@ -696,7 +711,7 @@ bool Page::loadThumb(unsigned char **data_out, int *width_out, int *height_out,
 
     if (data_out) {
         ImageStream imgstr { str, width, colorMap.getNumPixelComps(), colorMap.getBits() };
-        if (!imgstr.reset()) {
+        if (!imgstr.rewind()) {
             return false;
         }
         unsigned char *pixbufdata = (unsigned char *)gmalloc(pixbufdatasize);
