@@ -274,7 +274,7 @@ SplashError SplashBitmap::writeAlphaPGMFile(char *fileName)
     return splashOk;
 }
 
-void SplashBitmap::getPixel(int x, int y, SplashColorPtr pixel)
+void SplashBitmap::getPixel(int x, int y, SplashColorPtr pixel) const
 {
     SplashColorPtr p;
 
@@ -356,7 +356,7 @@ SplashError SplashBitmap::writeImgFile(SplashImageFileFormat format, const char
 
 void SplashBitmap::setJpegParams(ImgWriter *writer, WriteImgParams *params)
 {
-#ifdef ENABLE_LIBJPEG
+#if ENABLE_LIBJPEG
     if (params) {
         static_cast<JpegWriter *>(writer)->setProgressive(params->jpegProgressive);
         static_cast<JpegWriter *>(writer)->setOptimize(params->jpegOptimize);
@@ -364,6 +364,9 @@ void SplashBitmap::setJpegParams(ImgWriter *writer, WriteImgParams *params)
             static_cast<JpegWriter *>(writer)->setQuality(params->jpegQuality);
         }
     }
+#else
+    (void)writer;
+    (void)params;
 #endif
 }
 
@@ -375,13 +378,13 @@ SplashError SplashBitmap::writeImgFile(SplashImageFileFormat format, FILE *f, do
     SplashColorMode imageWriterFormat = splashModeRGB8;
 
     switch (format) {
-#ifdef ENABLE_LIBPNG
+#if ENABLE_LIBPNG
     case splashFormatPng:
         writer = new PNGWriter();
         break;
 #endif
 
-#ifdef ENABLE_LIBJPEG
+#if ENABLE_LIBJPEG
     case splashFormatJpegCMYK:
         writer = new JpegWriter(JpegWriter::CMYK);
         setJpegParams(writer, params);
@@ -390,9 +393,11 @@ SplashError SplashBitmap::writeImgFile(SplashImageFileFormat format, FILE *f, do
         writer = new JpegWriter();
         setJpegParams(writer, params);
         break;
+#else
+        (void)params;
 #endif
 
-#ifdef ENABLE_LIBTIFF
+#if ENABLE_LIBTIFF
     case splashFormatTiff:
         switch (mode) {
         case splashModeMono1:
@@ -419,6 +424,8 @@ SplashError SplashBitmap::writeImgFile(SplashImageFileFormat format, FILE *f, do
             ((TiffWriter *)writer)->setCompressionString(params->tiffCompression.c_str());
         }
         break;
+#else
+        (void)params;
 #endif
 
     default:
